@@ -6,7 +6,7 @@ package Mite::Compiled;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006001';
+our $VERSION   = '0.006002';
 
 use Path::Tiny;
 
@@ -57,7 +57,7 @@ sub compile {
             );
         }
         !$flag;
-    } and length($tidied) and ( $code = $tidied );
+    } and defined($tidied) and length($tidied) and ($code = $tidied);
 
     return $code;
 }
